##  Step 1. Enrich Data
In this step, you will add [Initiatives](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.") (using Program and Project Fact Sheet subtypes (including hierarchies)) and Milestones (available with the Architecture and Road Map Planning) to your SAP LeanIX Inventory. This is crucial to create a high-level plan and structure for your transformation. It also sets the basis to create a detailed target architecture in [phase 3 (Explore)](https://help.sap.com/docs/leanix/ea/erp-transformation-explore?locale=en-US&state=PRODUCTION&version=CLOUD "Detail the impact of the transformation on your landscape and refine the target architecture.") using Transformation and Impact features (available with the Architecture and Road Map Planning).
In this step, it is important to involve the rest of the ERP Transformation roles (such as Program and Project Managers) to get an overview of all planned Initiatives, Programs, and/or Projects, and to create ownership for maintaining this data moving forward. These roles can be added as Subscription Roles to the respective Fact Sheets. Typically, the EA team will kick off this process by building an initial structure in SAP LeanIX.
**Note**
To leverage the full potential of SAP LeanIX for this and the following step, you will need to activate [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management."), which was previously known as BTM module. It is a separate product that needs to be purchased. Only with Architecture and Road Map Planning, you will be able to transform your landscape and see changes and impacts on a timeline, by visualizing your target (to-be) architecture. In this step, you will benefit from Architecture and Road Map Planning by adding Milestones which will enrich your Reporting and set the foundation to create your target architecture in phase 3.
